*****************
Distance Measures
*****************

.. automodule:: networkx.algorithms.distance_measures
.. autosummary::
   :toctree: generated/

   barycenter
   center
   diameter
   eccentricity
   extrema_bounding
   periphery
   radius
   resistance_distance


